@@ -104,6 +104,7 @@
 
   function slideOut() {
     root.removeClass("menu-open");
+    $('#ftw-mobile-menu').trigger('mobilenav:nav:willclose');
     root.on(vendorTransitionEnd.join(" "), function() {
       root.removeClass("menu-opened");
       root.addClass("menu-closed");
@@ -119,6 +120,7 @@
 
   function slideIn() {
     root.addClass("menu-open");
+    $('#ftw-mobile-menu').trigger('mobilenav:nav:willopen');
     root.on(vendorTransitionEnd.join(" "), function() {
       root.addClass("menu-opened");
       root.removeClass("menu-closed");
@@ -354,6 +356,12 @@
     }
   })
   .ready(function() {
+
+    if ($('#ftw-mobile-wrapper').length === 0) {
+      // Do not anything, since ftw.mobile html structure is not available
+      return;
+    }
+
     Handlebars.registerPartial("list", $("#ftw-mobile-navigation-list-template").html());
 
     var translations = $("#ftw-mobile-menu-buttons").data('i18n');
